var config = {
    type: Phaser.AUTO,
    width: 800,
    height: 600,
    physics: {
        default: 'arcade',
        arcade: {
            gravity: { y: 300 },
            debug: true
        }
    },
    scene: {
        preload: preload,
        create: create,
        update: update
    }
};

var game = new Phaser.Game(config);
var scene, player, platforms;
var cursors;

function preload() {
	this.load.image('sky','assets/sky.png');
	this.load
	.spritesheet('dude','assets/dude.png', 
		{ frameWidth: 32, frameHeight: 48});
	this.load.image('platform','assets/platform.png');
}

function create() {
	scene = this;
	initWorld();
	initPlayer();
	this.physics.add.collider(player, platforms);
	cursors = this.input.keyboard.createCursorKeys();
}

function initWorld() {
	//this.add.image(400,300,'sky');
	scene.add.image(0,0,'sky').setOrigin(0,0);
	platforms = scene.physics.add.staticGroup();
	platforms.create(400,400,'platform')
		.setScale(2).refreshBody();
}

function initPlayer() {
	player = scene.physics.add.sprite(100,100,'dude');
	player.setCollideWorldBounds(true);
	scene.anims.create({
		key: 'runleft',
		frames: scene.anims.
			generateFrameNumbers('dude', {start: 0, end: 3}),
		frameRate: 10,
		repeat: -1
	});
	scene.anims.create({
		key: 'runright',
		frames: scene.anims.
			generateFrameNumbers('dude', {start: 5, end: 8}),
		frameRate: 10,
		repeat: -1
	});
	scene.anims.create({
		key: 'stand',
		frames: [{ key: 'dude', frame: 4}],
		frameRate: 10,
		repeat: -1
	});
	player.anims.play('stand');
}

function update() {
	if (cursors.left.isDown) {
		player.setVelocityX(-160);
		player.anims.play('runleft', true);
	} else if (cursors.right.isDown) {
		player.setVelocityX(160);
		player.anims.play('runright', true);
	} else {
		player.setVelocityX(0);
		player.anims.play('stand');		
	}
	if (cursors.up.isDown) {
		player.setVelocityY(-330);
	}
}


